==> ovirt-engine-3.5.6.2.tar.gz: frontend/webadmin/modules/uicommonweb/src/main/java/org/ovirt/engine/ui/uicommonweb/models/quota/ChangeQuotaItemModel.java <==
package org.ovirt.engine.ui.uicommonweb.models.quota;

import org.ovirt.engine.core.common.businessentities.Quota;
import org.ovirt.engine.core.compat.Guid;
import org.ovirt.engine.ui.uicommonweb.models.EntityModel;
import org.ovirt.engine.ui.uicommonweb.models.ListModel;

public class ChangeQuotaItemModel extends EntityModel {
    EntityModel<String> object;
    EntityModel<String> currentQuota;
    ListModel<Quota> quota;
    private Guid storageDomainId;
    private String storageDomainName;

    public ChangeQuotaItemModel() {
        object = new EntityModel<String>();
        currentQuota = new EntityModel<String>();
        quota = new ListModel<Quota>();
    }

    public EntityModel<String> getObject() {
        return object;
    }

    public void setObject(EntityModel<String> object) {
        this.object = object;
    }

    public EntityModel<String> getCurrentQuota() {
        return currentQuota;
    }

    public void setCurrentQuota(EntityModel<String> currentQuota) {
        this.currentQuota = currentQuota;
    }

    public ListModel<Quota> getQuota() {
        return quota;
    }

    public void setQuota(ListModel<Quota> quota) {
        this.quota = quota;
    }

    public Guid getStorageDomainId() {
        return storageDomainId;
    }

    public void setStorageDomainId(Guid storageDomainId) {
        this.storageDomainId = storageDomainId;
    }

    public String getStorageDomainName() {
        return storageDomainName;
    }

    public void setStorageDomainName(String storageDomainName) {
        this.storageDomainName = storageDomainName;
    }

}

==> ovirt-engine-3.6.3.3.tar.gz: frontend/webadmin/modules/uicommonweb/src/main/java/org/ovirt/engine/ui/uicommonweb/models/quota/ChangeQuotaItemModel.java <==
package org.ovirt.engine.ui.uicommonweb.models.quota;

import org.ovirt.engine.core.common.businessentities.Quota;
import org.ovirt.engine.core.common.businessentities.storage.DiskImage;
import org.ovirt.engine.core.compat.Guid;
import org.ovirt.engine.ui.uicommonweb.models.EntityModel;
import org.ovirt.engine.ui.uicommonweb.models.ListModel;

public class ChangeQuotaItemModel extends EntityModel<DiskImage> {
    EntityModel<String> object;
    EntityModel<String> currentQuota;
    ListModel<Quota> quota;
    private Guid storageDomainId;
    private String storageDomainName;

    public ChangeQuotaItemModel() {
        object = new EntityModel<String>();
        currentQuota = new EntityModel<String>();
        quota = new ListModel<Quota>();
    }

    public EntityModel<String> getObject() {
        return object;
    }

    public void setObject(EntityModel<String> object) {
        this.object = object;
    }

    public EntityModel<String> getCurrentQuota() {
        return currentQuota;
    }

    public void setCurrentQuota(EntityModel<String> currentQuota) {
        this.currentQuota = currentQuota;
    }

    public ListModel<Quota> getQuota() {
        return quota;
    }

    public void setQuota(ListModel<Quota> quota) {
        this.quota = quota;
    }

    public Guid getStorageDomainId() {
        return storageDomainId;
    }

    public void setStorageDomainId(Guid storageDomainId) {
        this.storageDomainId = storageDomainId;
    }

    public String getStorageDomainName() {
        return storageDomainName;
    }

    public void setStorageDomainName(String storageDomainName) {
        this.storageDomainName = storageDomainName;
    }

}
